@@ -1,7 +1,7 @@
 /*
     Qalculate (GTK+ UI)
 
-    Copyright (C) 2003-2007, 2008, 2016-2020  Hanna Knutsson (hanna.knutsson@protonmail.com)
+    Copyright (C) 2003-2007, 2008, 2016-2021  Hanna Knutsson (hanna.knutsson@protonmail.com)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,6 +17,9 @@
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <glib/gstdio.h>
+#ifdef G_OS_UNIX
+#include <glib-unix.h>
+#endif
 #include <unistd.h>
 #include <sys/stat.h>
 
@@ -59,6 +62,7 @@ extern PrintOptions printops;
 extern bool ignore_locale;
 extern bool title_modified;
 extern bool minimal_mode;
+extern gint hidden_x, hidden_y;
 bool check_version = false;
 string custom_title;
 
@@ -135,6 +139,13 @@ gboolean create_menus_etc(gpointer) {
 
 }
 
+#ifdef G_OS_UNIX
+static gboolean on_sigterm_received(gpointer) {
+	on_gcalc_exit(NULL, NULL, NULL);
+	return G_SOURCE_REMOVE;
+}
+#endif
+
 void create_application(GtkApplication *app) {
 
 #if GTK_MAJOR_VERSION > 3 || GTK_MINOR_VERSION >= 14
@@ -317,16 +328,28 @@ void create_application(GtkApplication *app) {
 		}
 	}
 
+#ifdef G_OS_UNIX
+	GSource *source = g_unix_signal_source_new(SIGTERM);
+	g_source_set_callback(source, on_sigterm_received, NULL, NULL);
+	g_source_attach(source, NULL);
+	g_source_unref(source);
+#endif
+
 }
 
 static void qalculate_activate(GtkApplication *app) {
 
 	GList *list;
 
-	list = gtk_application_get_windows (app);
+	list = gtk_application_get_windows(app);
 
 	if(list) {
-		gtk_window_present(GTK_WINDOW(list->data));
+		if(hidden_x >= 0) {
+			gtk_widget_show(GTK_WIDGET(list->data));
+			gtk_window_move(GTK_WINDOW(list->data), hidden_x, hidden_y);
+			hidden_x = -1;
+		}
+		gtk_window_present_with_time(GTK_WINDOW(list->data), GDK_CURRENT_TIME);
 		return;
 	}
 
@@ -432,7 +455,12 @@ static gint qalculate_command_line(GtkApplication *app, GApplicationCommandLine
 			title_modified = true;
 			g_free(str);
 		}
-		gtk_window_present(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")));
+		if(hidden_x >= 0) {
+			gtk_widget_show(GTK_WIDGET(gtk_builder_get_object(main_builder, "main_window")));
+			gtk_window_move(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")), hidden_x, hidden_y);
+			hidden_x = -1;
+		}
+		gtk_window_present_with_time(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")), GDK_CURRENT_TIME);
 		if(!file_arg.empty()) execute_from_file(file_arg);
 		if(!calc_arg.empty()) {
 			gtk_text_buffer_set_text(GTK_TEXT_BUFFER(gtk_builder_get_object(main_builder, "expressionbuffer")), calc_arg.c_str(), -1);
